<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-stats?lang_cible=it
// ** ne pas modifier le fichier **

return [

	// S
	'stats_description' => 'Statistiche di SPIP',
	'stats_nom' => 'Statistiche',
	'stats_slogan' => 'Gestione delle statistiche di SPIP',
];
